nxp-pac

Crates

git

Versions

mimxrt1011

Flavors

Dma

Struct Dma 

pub struct Dma { /* private fields */ }
DMA

Implementations

Source

impl Dma

pub const unsafe fn from_ptr(ptr: *mut ()) -> Self

pub const fn as_ptr(&self) -> *mut ()

pub const fn cr(self) -> Reg<Cr, RW>

Control

pub const fn es(self) -> Reg<Es, R>

Error Status

pub const fn erq(self) -> Reg<Erq, RW>

Enable Request

pub const fn eei(self) -> Reg<Eei, RW>

Enable Error Interrupt

pub const fn ceei(self) -> Reg<Ceei, RW>

Clear Enable Error Interrupt

pub const fn seei(self) -> Reg<Seei, RW>

Set Enable Error Interrupt

pub const fn cerq(self) -> Reg<Cerq, RW>

Clear Enable Request

pub const fn serq(self) -> Reg<Serq, RW>

Set Enable Request

pub const fn cdne(self) -> Reg<Cdne, RW>

Clear DONE Status Bit

pub const fn ssrt(self) -> Reg<Ssrt, RW>

Set START Bit

pub const fn cerr(self) -> Reg<Cerr, RW>

Clear Error

pub const fn cint(self) -> Reg<Cint, RW>

Clear Interrupt Request

pub const fn int(self) -> Reg<Int, RW>

Interrupt Request

pub const fn err(self) -> Reg<Err, RW>

Error

pub const fn hrs(self) -> Reg<Hrs, R>

Hardware Request Status

pub const fn ears(self) -> Reg<Ears, RW>

Enable Asynchronous Request in Stop

pub const fn dchpri3(self) -> Reg<Dchpri, RW>

Channel Priority

pub const fn dchpri2(self) -> Reg<Dchpri, RW>

Channel Priority

pub const fn dchpri1(self) -> Reg<Dchpri, RW>

Channel Priority

pub const fn dchpri0(self) -> Reg<Dchpri, RW>

Channel Priority

pub const fn dchpri7(self) -> Reg<Dchpri, RW>

Channel Priority

pub const fn dchpri6(self) -> Reg<Dchpri, RW>

Channel Priority

pub const fn dchpri5(self) -> Reg<Dchpri, RW>

Channel Priority

pub const fn dchpri4(self) -> Reg<Dchpri, RW>

Channel Priority

pub const fn dchpri11(self) -> Reg<Dchpri, RW>

Channel Priority

pub const fn dchpri10(self) -> Reg<Dchpri, RW>

Channel Priority

pub const fn dchpri9(self) -> Reg<Dchpri, RW>

Channel Priority

pub const fn dchpri8(self) -> Reg<Dchpri, RW>

Channel Priority

pub const fn dchpri15(self) -> Reg<Dchpri, RW>

Channel Priority

pub const fn dchpri14(self) -> Reg<Dchpri, RW>

Channel Priority

pub const fn dchpri13(self) -> Reg<Dchpri, RW>

Channel Priority

pub const fn dchpri12(self) -> Reg<Dchpri, RW>

Channel Priority

pub const fn tcd0_saddr(self) -> Reg<TcdSaddr, RW>

TCD Source Address

pub const fn tcd0_soff(self) -> Reg<TcdSoff, RW>

TCD Signed Source Address Offset

pub const fn tcd0_attr(self) -> Reg<TcdAttr, RW>

TCD Transfer Attributes

pub const fn tcd0_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>

TCD Minor Byte Count (Minor Loop Mapping Disabled)

pub const fn tcd0_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>

TCD Signed Minor Loop Offset (Minor Loop Mapping Enabled and Offset Disabled)

pub const fn tcd0_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>

TCD Signed Minor Loop Offset (Minor Loop Mapping and Offset Enabled)

pub const fn tcd0_slast(self) -> Reg<TcdSlast, RW>

TCD Last Source Address Adjustment

pub const fn tcd0_daddr(self) -> Reg<TcdDaddr, RW>

TCD Destination Address

pub const fn tcd0_doff(self) -> Reg<TcdDoff, RW>

TCD Signed Destination Address Offset

pub const fn tcd0_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>

TCD Current Minor Loop Link, Major Loop Count (Channel Linking Disabled)

pub const fn tcd0_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>

TCD Current Minor Loop Link, Major Loop Count (Channel Linking Enabled)

pub const fn tcd0_dlastsga(self) -> Reg<TcdDlastsga, RW>

TCD Last Destination Address Adjustment/Scatter Gather Address

pub const fn tcd0_csr(self) -> Reg<TcdCsr, RW>

TCD Control and Status

pub const fn tcd0_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>

TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Disabled)

pub const fn tcd0_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>

TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Enabled)

pub const fn tcd1_saddr(self) -> Reg<TcdSaddr, RW>

TCD Source Address

pub const fn tcd1_soff(self) -> Reg<TcdSoff, RW>

TCD Signed Source Address Offset

pub const fn tcd1_attr(self) -> Reg<TcdAttr, RW>

TCD Transfer Attributes

pub const fn tcd1_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>

TCD Minor Byte Count (Minor Loop Mapping Disabled)

pub const fn tcd1_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>

TCD Signed Minor Loop Offset (Minor Loop Mapping Enabled and Offset Disabled)

pub const fn tcd1_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>

TCD Signed Minor Loop Offset (Minor Loop Mapping and Offset Enabled)

pub const fn tcd1_slast(self) -> Reg<TcdSlast, RW>

TCD Last Source Address Adjustment

pub const fn tcd1_daddr(self) -> Reg<TcdDaddr, RW>

TCD Destination Address

pub const fn tcd1_doff(self) -> Reg<TcdDoff, RW>

TCD Signed Destination Address Offset

pub const fn tcd1_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>

TCD Current Minor Loop Link, Major Loop Count (Channel Linking Disabled)

pub const fn tcd1_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>

TCD Current Minor Loop Link, Major Loop Count (Channel Linking Enabled)

pub const fn tcd1_dlastsga(self) -> Reg<TcdDlastsga, RW>

TCD Last Destination Address Adjustment/Scatter Gather Address

pub const fn tcd1_csr(self) -> Reg<TcdCsr, RW>

TCD Control and Status

pub const fn tcd1_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>

TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Disabled)

pub const fn tcd1_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>

TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Enabled)

pub const fn tcd2_saddr(self) -> Reg<TcdSaddr, RW>

TCD Source Address

pub const fn tcd2_soff(self) -> Reg<TcdSoff, RW>

TCD Signed Source Address Offset

pub const fn tcd2_attr(self) -> Reg<TcdAttr, RW>

TCD Transfer Attributes

pub const fn tcd2_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>

TCD Minor Byte Count (Minor Loop Mapping Disabled)

pub const fn tcd2_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>

TCD Signed Minor Loop Offset (Minor Loop Mapping Enabled and Offset Disabled)

pub const fn tcd2_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>

TCD Signed Minor Loop Offset (Minor Loop Mapping and Offset Enabled)

pub const fn tcd2_slast(self) -> Reg<TcdSlast, RW>

TCD Last Source Address Adjustment

pub const fn tcd2_daddr(self) -> Reg<TcdDaddr, RW>

TCD Destination Address

pub const fn tcd2_doff(self) -> Reg<TcdDoff, RW>

TCD Signed Destination Address Offset

pub const fn tcd2_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>

TCD Current Minor Loop Link, Major Loop Count (Channel Linking Disabled)

pub const fn tcd2_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>

TCD Current Minor Loop Link, Major Loop Count (Channel Linking Enabled)

pub const fn tcd2_dlastsga(self) -> Reg<TcdDlastsga, RW>

TCD Last Destination Address Adjustment/Scatter Gather Address

pub const fn tcd2_csr(self) -> Reg<TcdCsr, RW>

TCD Control and Status

pub const fn tcd2_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>

TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Disabled)

pub const fn tcd2_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>

TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Enabled)

pub const fn tcd3_saddr(self) -> Reg<TcdSaddr, RW>

TCD Source Address

pub const fn tcd3_soff(self) -> Reg<TcdSoff, RW>

TCD Signed Source Address Offset

pub const fn tcd3_attr(self) -> Reg<TcdAttr, RW>

TCD Transfer Attributes

pub const fn tcd3_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>

TCD Minor Byte Count (Minor Loop Mapping Disabled)

pub const fn tcd3_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>

TCD Signed Minor Loop Offset (Minor Loop Mapping Enabled and Offset Disabled)

pub const fn tcd3_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>

TCD Signed Minor Loop Offset (Minor Loop Mapping and Offset Enabled)

pub const fn tcd3_slast(self) -> Reg<TcdSlast, RW>

TCD Last Source Address Adjustment

pub const fn tcd3_daddr(self) -> Reg<TcdDaddr, RW>

TCD Destination Address

pub const fn tcd3_doff(self) -> Reg<TcdDoff, RW>

TCD Signed Destination Address Offset

pub const fn tcd3_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>

TCD Current Minor Loop Link, Major Loop Count (Channel Linking Disabled)

pub const fn tcd3_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>

TCD Current Minor Loop Link, Major Loop Count (Channel Linking Enabled)

pub const fn tcd3_dlastsga(self) -> Reg<TcdDlastsga, RW>

TCD Last Destination Address Adjustment/Scatter Gather Address

pub const fn tcd3_csr(self) -> Reg<TcdCsr, RW>

TCD Control and Status

pub const fn tcd3_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>

TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Disabled)

pub const fn tcd3_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>

TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Enabled)

pub const fn tcd4_saddr(self) -> Reg<TcdSaddr, RW>

TCD Source Address

pub const fn tcd4_soff(self) -> Reg<TcdSoff, RW>

TCD Signed Source Address Offset

pub const fn tcd4_attr(self) -> Reg<TcdAttr, RW>

TCD Transfer Attributes

pub const fn tcd4_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>

TCD Minor Byte Count (Minor Loop Mapping Disabled)

pub const fn tcd4_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>

TCD Signed Minor Loop Offset (Minor Loop Mapping Enabled and Offset Disabled)

pub const fn tcd4_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>

TCD Signed Minor Loop Offset (Minor Loop Mapping and Offset Enabled)

pub const fn tcd4_slast(self) -> Reg<TcdSlast, RW>

TCD Last Source Address Adjustment

pub const fn tcd4_daddr(self) -> Reg<TcdDaddr, RW>

TCD Destination Address

pub const fn tcd4_doff(self) -> Reg<TcdDoff, RW>

TCD Signed Destination Address Offset

pub const fn tcd4_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>

TCD Current Minor Loop Link, Major Loop Count (Channel Linking Disabled)

pub const fn tcd4_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>

TCD Current Minor Loop Link, Major Loop Count (Channel Linking Enabled)

pub const fn tcd4_dlastsga(self) -> Reg<TcdDlastsga, RW>

TCD Last Destination Address Adjustment/Scatter Gather Address

pub const fn tcd4_csr(self) -> Reg<TcdCsr, RW>

TCD Control and Status

pub const fn tcd4_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>

TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Disabled)

pub const fn tcd4_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>

TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Enabled)

pub const fn tcd5_saddr(self) -> Reg<TcdSaddr, RW>

TCD Source Address

pub const fn tcd5_soff(self) -> Reg<TcdSoff, RW>

TCD Signed Source Address Offset

pub const fn tcd5_attr(self) -> Reg<TcdAttr, RW>

TCD Transfer Attributes

pub const fn tcd5_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>

TCD Minor Byte Count (Minor Loop Mapping Disabled)

pub const fn tcd5_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>

TCD Signed Minor Loop Offset (Minor Loop Mapping Enabled and Offset Disabled)

pub const fn tcd5_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>

TCD Signed Minor Loop Offset (Minor Loop Mapping and Offset Enabled)

pub const fn tcd5_slast(self) -> Reg<TcdSlast, RW>

TCD Last Source Address Adjustment

pub const fn tcd5_daddr(self) -> Reg<TcdDaddr, RW>

TCD Destination Address

pub const fn tcd5_doff(self) -> Reg<TcdDoff, RW>

TCD Signed Destination Address Offset

pub const fn tcd5_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>

TCD Current Minor Loop Link, Major Loop Count (Channel Linking Disabled)

pub const fn tcd5_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>

TCD Current Minor Loop Link, Major Loop Count (Channel Linking Enabled)

pub const fn tcd5_dlastsga(self) -> Reg<TcdDlastsga, RW>

TCD Last Destination Address Adjustment/Scatter Gather Address

pub const fn tcd5_csr(self) -> Reg<TcdCsr, RW>

TCD Control and Status

pub const fn tcd5_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>

TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Disabled)

pub const fn tcd5_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>

TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Enabled)

pub const fn tcd6_saddr(self) -> Reg<TcdSaddr, RW>

TCD Source Address

pub const fn tcd6_soff(self) -> Reg<TcdSoff, RW>

TCD Signed Source Address Offset

pub const fn tcd6_attr(self) -> Reg<TcdAttr, RW>

TCD Transfer Attributes

pub const fn tcd6_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>

TCD Minor Byte Count (Minor Loop Mapping Disabled)

pub const fn tcd6_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>

TCD Signed Minor Loop Offset (Minor Loop Mapping Enabled and Offset Disabled)

pub const fn tcd6_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>

TCD Signed Minor Loop Offset (Minor Loop Mapping and Offset Enabled)

pub const fn tcd6_slast(self) -> Reg<TcdSlast, RW>

TCD Last Source Address Adjustment

pub const fn tcd6_daddr(self) -> Reg<TcdDaddr, RW>

TCD Destination Address

pub const fn tcd6_doff(self) -> Reg<TcdDoff, RW>

TCD Signed Destination Address Offset

pub const fn tcd6_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>

TCD Current Minor Loop Link, Major Loop Count (Channel Linking Disabled)

pub const fn tcd6_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>

TCD Current Minor Loop Link, Major Loop Count (Channel Linking Enabled)

pub const fn tcd6_dlastsga(self) -> Reg<TcdDlastsga, RW>

TCD Last Destination Address Adjustment/Scatter Gather Address

pub const fn tcd6_csr(self) -> Reg<TcdCsr, RW>

TCD Control and Status

pub const fn tcd6_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>

TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Disabled)

pub const fn tcd6_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>

TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Enabled)

pub const fn tcd7_saddr(self) -> Reg<TcdSaddr, RW>

TCD Source Address

pub const fn tcd7_soff(self) -> Reg<TcdSoff, RW>

TCD Signed Source Address Offset

pub const fn tcd7_attr(self) -> Reg<TcdAttr, RW>

TCD Transfer Attributes

pub const fn tcd7_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>

TCD Minor Byte Count (Minor Loop Mapping Disabled)

pub const fn tcd7_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>

TCD Signed Minor Loop Offset (Minor Loop Mapping Enabled and Offset Disabled)

pub const fn tcd7_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>

TCD Signed Minor Loop Offset (Minor Loop Mapping and Offset Enabled)

pub const fn tcd7_slast(self) -> Reg<TcdSlast, RW>

TCD Last Source Address Adjustment

pub const fn tcd7_daddr(self) -> Reg<TcdDaddr, RW>

TCD Destination Address

pub const fn tcd7_doff(self) -> Reg<TcdDoff, RW>

TCD Signed Destination Address Offset

pub const fn tcd7_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>

TCD Current Minor Loop Link, Major Loop Count (Channel Linking Disabled)

pub const fn tcd7_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>

TCD Current Minor Loop Link, Major Loop Count (Channel Linking Enabled)

pub const fn tcd7_dlastsga(self) -> Reg<TcdDlastsga, RW>

TCD Last Destination Address Adjustment/Scatter Gather Address

pub const fn tcd7_csr(self) -> Reg<TcdCsr, RW>

TCD Control and Status

pub const fn tcd7_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>

TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Disabled)

pub const fn tcd7_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>

TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Enabled)

pub const fn tcd8_saddr(self) -> Reg<TcdSaddr, RW>

TCD Source Address

pub const fn tcd8_soff(self) -> Reg<TcdSoff, RW>

TCD Signed Source Address Offset

pub const fn tcd8_attr(self) -> Reg<TcdAttr, RW>

TCD Transfer Attributes

pub const fn tcd8_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>

TCD Minor Byte Count (Minor Loop Mapping Disabled)

pub const fn tcd8_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>

TCD Signed Minor Loop Offset (Minor Loop Mapping Enabled and Offset Disabled)

pub const fn tcd8_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>

TCD Signed Minor Loop Offset (Minor Loop Mapping and Offset Enabled)

pub const fn tcd8_slast(self) -> Reg<TcdSlast, RW>

TCD Last Source Address Adjustment

pub const fn tcd8_daddr(self) -> Reg<TcdDaddr, RW>

TCD Destination Address

pub const fn tcd8_doff(self) -> Reg<TcdDoff, RW>

TCD Signed Destination Address Offset

pub const fn tcd8_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>

TCD Current Minor Loop Link, Major Loop Count (Channel Linking Disabled)

pub const fn tcd8_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>

TCD Current Minor Loop Link, Major Loop Count (Channel Linking Enabled)

pub const fn tcd8_dlastsga(self) -> Reg<TcdDlastsga, RW>

TCD Last Destination Address Adjustment/Scatter Gather Address

pub const fn tcd8_csr(self) -> Reg<TcdCsr, RW>

TCD Control and Status

pub const fn tcd8_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>

TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Disabled)

pub const fn tcd8_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>

TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Enabled)

pub const fn tcd9_saddr(self) -> Reg<TcdSaddr, RW>

TCD Source Address

pub const fn tcd9_soff(self) -> Reg<TcdSoff, RW>

TCD Signed Source Address Offset

pub const fn tcd9_attr(self) -> Reg<TcdAttr, RW>

TCD Transfer Attributes

pub const fn tcd9_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>

TCD Minor Byte Count (Minor Loop Mapping Disabled)

pub const fn tcd9_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>

TCD Signed Minor Loop Offset (Minor Loop Mapping Enabled and Offset Disabled)

pub const fn tcd9_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>

TCD Signed Minor Loop Offset (Minor Loop Mapping and Offset Enabled)

pub const fn tcd9_slast(self) -> Reg<TcdSlast, RW>

TCD Last Source Address Adjustment

pub const fn tcd9_daddr(self) -> Reg<TcdDaddr, RW>

TCD Destination Address

pub const fn tcd9_doff(self) -> Reg<TcdDoff, RW>

TCD Signed Destination Address Offset

pub const fn tcd9_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>

TCD Current Minor Loop Link, Major Loop Count (Channel Linking Disabled)

pub const fn tcd9_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>

TCD Current Minor Loop Link, Major Loop Count (Channel Linking Enabled)

pub const fn tcd9_dlastsga(self) -> Reg<TcdDlastsga, RW>

TCD Last Destination Address Adjustment/Scatter Gather Address

pub const fn tcd9_csr(self) -> Reg<TcdCsr, RW>

TCD Control and Status

pub const fn tcd9_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>

TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Disabled)

pub const fn tcd9_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>

TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Enabled)

pub const fn tcd10_saddr(self) -> Reg<TcdSaddr, RW>

TCD Source Address

pub const fn tcd10_soff(self) -> Reg<TcdSoff, RW>

TCD Signed Source Address Offset

pub const fn tcd10_attr(self) -> Reg<TcdAttr, RW>

TCD Transfer Attributes

pub const fn tcd10_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>

TCD Minor Byte Count (Minor Loop Mapping Disabled)

pub const fn tcd10_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>

TCD Signed Minor Loop Offset (Minor Loop Mapping Enabled and Offset Disabled)

pub const fn tcd10_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>

TCD Signed Minor Loop Offset (Minor Loop Mapping and Offset Enabled)

pub const fn tcd10_slast(self) -> Reg<TcdSlast, RW>

TCD Last Source Address Adjustment

pub const fn tcd10_daddr(self) -> Reg<TcdDaddr, RW>

TCD Destination Address

pub const fn tcd10_doff(self) -> Reg<TcdDoff, RW>

TCD Signed Destination Address Offset

pub const fn tcd10_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>

TCD Current Minor Loop Link, Major Loop Count (Channel Linking Disabled)

pub const fn tcd10_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>

TCD Current Minor Loop Link, Major Loop Count (Channel Linking Enabled)

pub const fn tcd10_dlastsga(self) -> Reg<TcdDlastsga, RW>

TCD Last Destination Address Adjustment/Scatter Gather Address

pub const fn tcd10_csr(self) -> Reg<TcdCsr, RW>

TCD Control and Status

pub const fn tcd10_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>

TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Disabled)

pub const fn tcd10_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>

TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Enabled)

pub const fn tcd11_saddr(self) -> Reg<TcdSaddr, RW>

TCD Source Address

pub const fn tcd11_soff(self) -> Reg<TcdSoff, RW>

TCD Signed Source Address Offset

pub const fn tcd11_attr(self) -> Reg<TcdAttr, RW>

TCD Transfer Attributes

pub const fn tcd11_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>

TCD Minor Byte Count (Minor Loop Mapping Disabled)

pub const fn tcd11_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>

TCD Signed Minor Loop Offset (Minor Loop Mapping Enabled and Offset Disabled)

pub const fn tcd11_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>

TCD Signed Minor Loop Offset (Minor Loop Mapping and Offset Enabled)

pub const fn tcd11_slast(self) -> Reg<TcdSlast, RW>

TCD Last Source Address Adjustment

pub const fn tcd11_daddr(self) -> Reg<TcdDaddr, RW>

TCD Destination Address

pub const fn tcd11_doff(self) -> Reg<TcdDoff, RW>

TCD Signed Destination Address Offset

pub const fn tcd11_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>

TCD Current Minor Loop Link, Major Loop Count (Channel Linking Disabled)

pub const fn tcd11_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>

TCD Current Minor Loop Link, Major Loop Count (Channel Linking Enabled)

pub const fn tcd11_dlastsga(self) -> Reg<TcdDlastsga, RW>

TCD Last Destination Address Adjustment/Scatter Gather Address

pub const fn tcd11_csr(self) -> Reg<TcdCsr, RW>

TCD Control and Status

pub const fn tcd11_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>

TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Disabled)

pub const fn tcd11_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>

TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Enabled)

pub const fn tcd12_saddr(self) -> Reg<TcdSaddr, RW>

TCD Source Address

pub const fn tcd12_soff(self) -> Reg<TcdSoff, RW>

TCD Signed Source Address Offset

pub const fn tcd12_attr(self) -> Reg<TcdAttr, RW>

TCD Transfer Attributes

pub const fn tcd12_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>

TCD Minor Byte Count (Minor Loop Mapping Disabled)

pub const fn tcd12_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>

TCD Signed Minor Loop Offset (Minor Loop Mapping Enabled and Offset Disabled)

pub const fn tcd12_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>

TCD Signed Minor Loop Offset (Minor Loop Mapping and Offset Enabled)

pub const fn tcd12_slast(self) -> Reg<TcdSlast, RW>

TCD Last Source Address Adjustment

pub const fn tcd12_daddr(self) -> Reg<TcdDaddr, RW>

TCD Destination Address

pub const fn tcd12_doff(self) -> Reg<TcdDoff, RW>

TCD Signed Destination Address Offset

pub const fn tcd12_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>

TCD Current Minor Loop Link, Major Loop Count (Channel Linking Disabled)

pub const fn tcd12_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>

TCD Current Minor Loop Link, Major Loop Count (Channel Linking Enabled)

pub const fn tcd12_dlastsga(self) -> Reg<TcdDlastsga, RW>

TCD Last Destination Address Adjustment/Scatter Gather Address

pub const fn tcd12_csr(self) -> Reg<TcdCsr, RW>

TCD Control and Status

pub const fn tcd12_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>

TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Disabled)

pub const fn tcd12_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>

TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Enabled)

pub const fn tcd13_saddr(self) -> Reg<TcdSaddr, RW>

TCD Source Address

pub const fn tcd13_soff(self) -> Reg<TcdSoff, RW>

TCD Signed Source Address Offset

pub const fn tcd13_attr(self) -> Reg<TcdAttr, RW>

TCD Transfer Attributes

pub const fn tcd13_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>

TCD Minor Byte Count (Minor Loop Mapping Disabled)

pub const fn tcd13_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>

TCD Signed Minor Loop Offset (Minor Loop Mapping Enabled and Offset Disabled)

pub const fn tcd13_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>

TCD Signed Minor Loop Offset (Minor Loop Mapping and Offset Enabled)

pub const fn tcd13_slast(self) -> Reg<TcdSlast, RW>

TCD Last Source Address Adjustment

pub const fn tcd13_daddr(self) -> Reg<TcdDaddr, RW>

TCD Destination Address

pub const fn tcd13_doff(self) -> Reg<TcdDoff, RW>

TCD Signed Destination Address Offset

pub const fn tcd13_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>

TCD Current Minor Loop Link, Major Loop Count (Channel Linking Disabled)

pub const fn tcd13_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>

TCD Current Minor Loop Link, Major Loop Count (Channel Linking Enabled)

pub const fn tcd13_dlastsga(self) -> Reg<TcdDlastsga, RW>

TCD Last Destination Address Adjustment/Scatter Gather Address

pub const fn tcd13_csr(self) -> Reg<TcdCsr, RW>

TCD Control and Status

pub const fn tcd13_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>

TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Disabled)

pub const fn tcd13_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>

TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Enabled)

pub const fn tcd14_saddr(self) -> Reg<TcdSaddr, RW>

TCD Source Address

pub const fn tcd14_soff(self) -> Reg<TcdSoff, RW>

TCD Signed Source Address Offset

pub const fn tcd14_attr(self) -> Reg<TcdAttr, RW>

TCD Transfer Attributes

pub const fn tcd14_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>

TCD Minor Byte Count (Minor Loop Mapping Disabled)

pub const fn tcd14_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>

TCD Signed Minor Loop Offset (Minor Loop Mapping Enabled and Offset Disabled)

pub const fn tcd14_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>

TCD Signed Minor Loop Offset (Minor Loop Mapping and Offset Enabled)

pub const fn tcd14_slast(self) -> Reg<TcdSlast, RW>

TCD Last Source Address Adjustment

pub const fn tcd14_daddr(self) -> Reg<TcdDaddr, RW>

TCD Destination Address

pub const fn tcd14_doff(self) -> Reg<TcdDoff, RW>

TCD Signed Destination Address Offset

pub const fn tcd14_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>

TCD Current Minor Loop Link, Major Loop Count (Channel Linking Disabled)

pub const fn tcd14_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>

TCD Current Minor Loop Link, Major Loop Count (Channel Linking Enabled)

pub const fn tcd14_dlastsga(self) -> Reg<TcdDlastsga, RW>

TCD Last Destination Address Adjustment/Scatter Gather Address

pub const fn tcd14_csr(self) -> Reg<TcdCsr, RW>

TCD Control and Status

pub const fn tcd14_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>

TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Disabled)

pub const fn tcd14_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>

TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Enabled)

pub const fn tcd15_saddr(self) -> Reg<TcdSaddr, RW>

TCD Source Address

pub const fn tcd15_soff(self) -> Reg<TcdSoff, RW>

TCD Signed Source Address Offset

pub const fn tcd15_attr(self) -> Reg<TcdAttr, RW>

TCD Transfer Attributes

pub const fn tcd15_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>

TCD Minor Byte Count (Minor Loop Mapping Disabled)

pub const fn tcd15_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>

TCD Signed Minor Loop Offset (Minor Loop Mapping Enabled and Offset Disabled)

pub const fn tcd15_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>

TCD Signed Minor Loop Offset (Minor Loop Mapping and Offset Enabled)

pub const fn tcd15_slast(self) -> Reg<TcdSlast, RW>

TCD Last Source Address Adjustment

pub const fn tcd15_daddr(self) -> Reg<TcdDaddr, RW>

TCD Destination Address

pub const fn tcd15_doff(self) -> Reg<TcdDoff, RW>

TCD Signed Destination Address Offset

pub const fn tcd15_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>

TCD Current Minor Loop Link, Major Loop Count (Channel Linking Disabled)

pub const fn tcd15_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>

TCD Current Minor Loop Link, Major Loop Count (Channel Linking Enabled)

pub const fn tcd15_dlastsga(self) -> Reg<TcdDlastsga, RW>

TCD Last Destination Address Adjustment/Scatter Gather Address

pub const fn tcd15_csr(self) -> Reg<TcdCsr, RW>

TCD Control and Status

pub const fn tcd15_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>

TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Disabled)

pub const fn tcd15_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>

TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Enabled)