pub struct Dma { /* private fields */ }Expand description
DMA
Implementations
Sourceimpl Dma
impl Dma
pub const unsafe fn from_ptr(ptr: *mut ()) -> Self
pub const fn as_ptr(&self) -> *mut ()
Sourcepub const fn tcd0_saddr(self) -> Reg<TcdSaddr, RW>
pub const fn tcd0_saddr(self) -> Reg<TcdSaddr, RW>
TCD Source Address
Sourcepub const fn tcd0_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>
pub const fn tcd0_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>
TCD Minor Byte Count (Minor Loop Mapping Disabled)
Sourcepub const fn tcd0_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>
pub const fn tcd0_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>
TCD Signed Minor Loop Offset (Minor Loop Mapping Enabled and Offset Disabled)
Sourcepub const fn tcd0_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>
pub const fn tcd0_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>
TCD Signed Minor Loop Offset (Minor Loop Mapping and Offset Enabled)
Sourcepub const fn tcd0_slast(self) -> Reg<TcdSlast, RW>
pub const fn tcd0_slast(self) -> Reg<TcdSlast, RW>
TCD Last Source Address Adjustment
Sourcepub const fn tcd0_daddr(self) -> Reg<TcdDaddr, RW>
pub const fn tcd0_daddr(self) -> Reg<TcdDaddr, RW>
TCD Destination Address
Sourcepub const fn tcd0_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>
pub const fn tcd0_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>
TCD Current Minor Loop Link, Major Loop Count (Channel Linking Disabled)
Sourcepub const fn tcd0_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>
pub const fn tcd0_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>
TCD Current Minor Loop Link, Major Loop Count (Channel Linking Enabled)
Sourcepub const fn tcd0_dlastsga(self) -> Reg<TcdDlastsga, RW>
pub const fn tcd0_dlastsga(self) -> Reg<TcdDlastsga, RW>
TCD Last Destination Address Adjustment/Scatter Gather Address
Sourcepub const fn tcd0_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>
pub const fn tcd0_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>
TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Disabled)
Sourcepub const fn tcd0_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>
pub const fn tcd0_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>
TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Enabled)
Sourcepub const fn tcd1_saddr(self) -> Reg<TcdSaddr, RW>
pub const fn tcd1_saddr(self) -> Reg<TcdSaddr, RW>
TCD Source Address
Sourcepub const fn tcd1_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>
pub const fn tcd1_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>
TCD Minor Byte Count (Minor Loop Mapping Disabled)
Sourcepub const fn tcd1_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>
pub const fn tcd1_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>
TCD Signed Minor Loop Offset (Minor Loop Mapping Enabled and Offset Disabled)
Sourcepub const fn tcd1_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>
pub const fn tcd1_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>
TCD Signed Minor Loop Offset (Minor Loop Mapping and Offset Enabled)
Sourcepub const fn tcd1_slast(self) -> Reg<TcdSlast, RW>
pub const fn tcd1_slast(self) -> Reg<TcdSlast, RW>
TCD Last Source Address Adjustment
Sourcepub const fn tcd1_daddr(self) -> Reg<TcdDaddr, RW>
pub const fn tcd1_daddr(self) -> Reg<TcdDaddr, RW>
TCD Destination Address
Sourcepub const fn tcd1_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>
pub const fn tcd1_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>
TCD Current Minor Loop Link, Major Loop Count (Channel Linking Disabled)
Sourcepub const fn tcd1_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>
pub const fn tcd1_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>
TCD Current Minor Loop Link, Major Loop Count (Channel Linking Enabled)
Sourcepub const fn tcd1_dlastsga(self) -> Reg<TcdDlastsga, RW>
pub const fn tcd1_dlastsga(self) -> Reg<TcdDlastsga, RW>
TCD Last Destination Address Adjustment/Scatter Gather Address
Sourcepub const fn tcd1_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>
pub const fn tcd1_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>
TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Disabled)
Sourcepub const fn tcd1_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>
pub const fn tcd1_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>
TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Enabled)
Sourcepub const fn tcd2_saddr(self) -> Reg<TcdSaddr, RW>
pub const fn tcd2_saddr(self) -> Reg<TcdSaddr, RW>
TCD Source Address
Sourcepub const fn tcd2_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>
pub const fn tcd2_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>
TCD Minor Byte Count (Minor Loop Mapping Disabled)
Sourcepub const fn tcd2_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>
pub const fn tcd2_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>
TCD Signed Minor Loop Offset (Minor Loop Mapping Enabled and Offset Disabled)
Sourcepub const fn tcd2_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>
pub const fn tcd2_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>
TCD Signed Minor Loop Offset (Minor Loop Mapping and Offset Enabled)
Sourcepub const fn tcd2_slast(self) -> Reg<TcdSlast, RW>
pub const fn tcd2_slast(self) -> Reg<TcdSlast, RW>
TCD Last Source Address Adjustment
Sourcepub const fn tcd2_daddr(self) -> Reg<TcdDaddr, RW>
pub const fn tcd2_daddr(self) -> Reg<TcdDaddr, RW>
TCD Destination Address
Sourcepub const fn tcd2_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>
pub const fn tcd2_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>
TCD Current Minor Loop Link, Major Loop Count (Channel Linking Disabled)
Sourcepub const fn tcd2_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>
pub const fn tcd2_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>
TCD Current Minor Loop Link, Major Loop Count (Channel Linking Enabled)
Sourcepub const fn tcd2_dlastsga(self) -> Reg<TcdDlastsga, RW>
pub const fn tcd2_dlastsga(self) -> Reg<TcdDlastsga, RW>
TCD Last Destination Address Adjustment/Scatter Gather Address
Sourcepub const fn tcd2_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>
pub const fn tcd2_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>
TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Disabled)
Sourcepub const fn tcd2_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>
pub const fn tcd2_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>
TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Enabled)
Sourcepub const fn tcd3_saddr(self) -> Reg<TcdSaddr, RW>
pub const fn tcd3_saddr(self) -> Reg<TcdSaddr, RW>
TCD Source Address
Sourcepub const fn tcd3_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>
pub const fn tcd3_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>
TCD Minor Byte Count (Minor Loop Mapping Disabled)
Sourcepub const fn tcd3_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>
pub const fn tcd3_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>
TCD Signed Minor Loop Offset (Minor Loop Mapping Enabled and Offset Disabled)
Sourcepub const fn tcd3_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>
pub const fn tcd3_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>
TCD Signed Minor Loop Offset (Minor Loop Mapping and Offset Enabled)
Sourcepub const fn tcd3_slast(self) -> Reg<TcdSlast, RW>
pub const fn tcd3_slast(self) -> Reg<TcdSlast, RW>
TCD Last Source Address Adjustment
Sourcepub const fn tcd3_daddr(self) -> Reg<TcdDaddr, RW>
pub const fn tcd3_daddr(self) -> Reg<TcdDaddr, RW>
TCD Destination Address
Sourcepub const fn tcd3_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>
pub const fn tcd3_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>
TCD Current Minor Loop Link, Major Loop Count (Channel Linking Disabled)
Sourcepub const fn tcd3_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>
pub const fn tcd3_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>
TCD Current Minor Loop Link, Major Loop Count (Channel Linking Enabled)
Sourcepub const fn tcd3_dlastsga(self) -> Reg<TcdDlastsga, RW>
pub const fn tcd3_dlastsga(self) -> Reg<TcdDlastsga, RW>
TCD Last Destination Address Adjustment/Scatter Gather Address
Sourcepub const fn tcd3_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>
pub const fn tcd3_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>
TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Disabled)
Sourcepub const fn tcd3_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>
pub const fn tcd3_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>
TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Enabled)
Sourcepub const fn tcd4_saddr(self) -> Reg<TcdSaddr, RW>
pub const fn tcd4_saddr(self) -> Reg<TcdSaddr, RW>
TCD Source Address
Sourcepub const fn tcd4_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>
pub const fn tcd4_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>
TCD Minor Byte Count (Minor Loop Mapping Disabled)
Sourcepub const fn tcd4_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>
pub const fn tcd4_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>
TCD Signed Minor Loop Offset (Minor Loop Mapping Enabled and Offset Disabled)
Sourcepub const fn tcd4_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>
pub const fn tcd4_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>
TCD Signed Minor Loop Offset (Minor Loop Mapping and Offset Enabled)
Sourcepub const fn tcd4_slast(self) -> Reg<TcdSlast, RW>
pub const fn tcd4_slast(self) -> Reg<TcdSlast, RW>
TCD Last Source Address Adjustment
Sourcepub const fn tcd4_daddr(self) -> Reg<TcdDaddr, RW>
pub const fn tcd4_daddr(self) -> Reg<TcdDaddr, RW>
TCD Destination Address
Sourcepub const fn tcd4_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>
pub const fn tcd4_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>
TCD Current Minor Loop Link, Major Loop Count (Channel Linking Disabled)
Sourcepub const fn tcd4_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>
pub const fn tcd4_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>
TCD Current Minor Loop Link, Major Loop Count (Channel Linking Enabled)
Sourcepub const fn tcd4_dlastsga(self) -> Reg<TcdDlastsga, RW>
pub const fn tcd4_dlastsga(self) -> Reg<TcdDlastsga, RW>
TCD Last Destination Address Adjustment/Scatter Gather Address
Sourcepub const fn tcd4_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>
pub const fn tcd4_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>
TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Disabled)
Sourcepub const fn tcd4_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>
pub const fn tcd4_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>
TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Enabled)
Sourcepub const fn tcd5_saddr(self) -> Reg<TcdSaddr, RW>
pub const fn tcd5_saddr(self) -> Reg<TcdSaddr, RW>
TCD Source Address
Sourcepub const fn tcd5_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>
pub const fn tcd5_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>
TCD Minor Byte Count (Minor Loop Mapping Disabled)
Sourcepub const fn tcd5_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>
pub const fn tcd5_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>
TCD Signed Minor Loop Offset (Minor Loop Mapping Enabled and Offset Disabled)
Sourcepub const fn tcd5_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>
pub const fn tcd5_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>
TCD Signed Minor Loop Offset (Minor Loop Mapping and Offset Enabled)
Sourcepub const fn tcd5_slast(self) -> Reg<TcdSlast, RW>
pub const fn tcd5_slast(self) -> Reg<TcdSlast, RW>
TCD Last Source Address Adjustment
Sourcepub const fn tcd5_daddr(self) -> Reg<TcdDaddr, RW>
pub const fn tcd5_daddr(self) -> Reg<TcdDaddr, RW>
TCD Destination Address
Sourcepub const fn tcd5_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>
pub const fn tcd5_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>
TCD Current Minor Loop Link, Major Loop Count (Channel Linking Disabled)
Sourcepub const fn tcd5_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>
pub const fn tcd5_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>
TCD Current Minor Loop Link, Major Loop Count (Channel Linking Enabled)
Sourcepub const fn tcd5_dlastsga(self) -> Reg<TcdDlastsga, RW>
pub const fn tcd5_dlastsga(self) -> Reg<TcdDlastsga, RW>
TCD Last Destination Address Adjustment/Scatter Gather Address
Sourcepub const fn tcd5_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>
pub const fn tcd5_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>
TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Disabled)
Sourcepub const fn tcd5_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>
pub const fn tcd5_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>
TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Enabled)
Sourcepub const fn tcd6_saddr(self) -> Reg<TcdSaddr, RW>
pub const fn tcd6_saddr(self) -> Reg<TcdSaddr, RW>
TCD Source Address
Sourcepub const fn tcd6_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>
pub const fn tcd6_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>
TCD Minor Byte Count (Minor Loop Mapping Disabled)
Sourcepub const fn tcd6_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>
pub const fn tcd6_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>
TCD Signed Minor Loop Offset (Minor Loop Mapping Enabled and Offset Disabled)
Sourcepub const fn tcd6_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>
pub const fn tcd6_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>
TCD Signed Minor Loop Offset (Minor Loop Mapping and Offset Enabled)
Sourcepub const fn tcd6_slast(self) -> Reg<TcdSlast, RW>
pub const fn tcd6_slast(self) -> Reg<TcdSlast, RW>
TCD Last Source Address Adjustment
Sourcepub const fn tcd6_daddr(self) -> Reg<TcdDaddr, RW>
pub const fn tcd6_daddr(self) -> Reg<TcdDaddr, RW>
TCD Destination Address
Sourcepub const fn tcd6_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>
pub const fn tcd6_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>
TCD Current Minor Loop Link, Major Loop Count (Channel Linking Disabled)
Sourcepub const fn tcd6_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>
pub const fn tcd6_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>
TCD Current Minor Loop Link, Major Loop Count (Channel Linking Enabled)
Sourcepub const fn tcd6_dlastsga(self) -> Reg<TcdDlastsga, RW>
pub const fn tcd6_dlastsga(self) -> Reg<TcdDlastsga, RW>
TCD Last Destination Address Adjustment/Scatter Gather Address
Sourcepub const fn tcd6_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>
pub const fn tcd6_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>
TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Disabled)
Sourcepub const fn tcd6_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>
pub const fn tcd6_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>
TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Enabled)
Sourcepub const fn tcd7_saddr(self) -> Reg<TcdSaddr, RW>
pub const fn tcd7_saddr(self) -> Reg<TcdSaddr, RW>
TCD Source Address
Sourcepub const fn tcd7_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>
pub const fn tcd7_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>
TCD Minor Byte Count (Minor Loop Mapping Disabled)
Sourcepub const fn tcd7_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>
pub const fn tcd7_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>
TCD Signed Minor Loop Offset (Minor Loop Mapping Enabled and Offset Disabled)
Sourcepub const fn tcd7_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>
pub const fn tcd7_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>
TCD Signed Minor Loop Offset (Minor Loop Mapping and Offset Enabled)
Sourcepub const fn tcd7_slast(self) -> Reg<TcdSlast, RW>
pub const fn tcd7_slast(self) -> Reg<TcdSlast, RW>
TCD Last Source Address Adjustment
Sourcepub const fn tcd7_daddr(self) -> Reg<TcdDaddr, RW>
pub const fn tcd7_daddr(self) -> Reg<TcdDaddr, RW>
TCD Destination Address
Sourcepub const fn tcd7_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>
pub const fn tcd7_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>
TCD Current Minor Loop Link, Major Loop Count (Channel Linking Disabled)
Sourcepub const fn tcd7_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>
pub const fn tcd7_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>
TCD Current Minor Loop Link, Major Loop Count (Channel Linking Enabled)
Sourcepub const fn tcd7_dlastsga(self) -> Reg<TcdDlastsga, RW>
pub const fn tcd7_dlastsga(self) -> Reg<TcdDlastsga, RW>
TCD Last Destination Address Adjustment/Scatter Gather Address
Sourcepub const fn tcd7_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>
pub const fn tcd7_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>
TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Disabled)
Sourcepub const fn tcd7_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>
pub const fn tcd7_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>
TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Enabled)
Sourcepub const fn tcd8_saddr(self) -> Reg<TcdSaddr, RW>
pub const fn tcd8_saddr(self) -> Reg<TcdSaddr, RW>
TCD Source Address
Sourcepub const fn tcd8_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>
pub const fn tcd8_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>
TCD Minor Byte Count (Minor Loop Mapping Disabled)
Sourcepub const fn tcd8_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>
pub const fn tcd8_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>
TCD Signed Minor Loop Offset (Minor Loop Mapping Enabled and Offset Disabled)
Sourcepub const fn tcd8_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>
pub const fn tcd8_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>
TCD Signed Minor Loop Offset (Minor Loop Mapping and Offset Enabled)
Sourcepub const fn tcd8_slast(self) -> Reg<TcdSlast, RW>
pub const fn tcd8_slast(self) -> Reg<TcdSlast, RW>
TCD Last Source Address Adjustment
Sourcepub const fn tcd8_daddr(self) -> Reg<TcdDaddr, RW>
pub const fn tcd8_daddr(self) -> Reg<TcdDaddr, RW>
TCD Destination Address
Sourcepub const fn tcd8_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>
pub const fn tcd8_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>
TCD Current Minor Loop Link, Major Loop Count (Channel Linking Disabled)
Sourcepub const fn tcd8_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>
pub const fn tcd8_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>
TCD Current Minor Loop Link, Major Loop Count (Channel Linking Enabled)
Sourcepub const fn tcd8_dlastsga(self) -> Reg<TcdDlastsga, RW>
pub const fn tcd8_dlastsga(self) -> Reg<TcdDlastsga, RW>
TCD Last Destination Address Adjustment/Scatter Gather Address
Sourcepub const fn tcd8_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>
pub const fn tcd8_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>
TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Disabled)
Sourcepub const fn tcd8_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>
pub const fn tcd8_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>
TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Enabled)
Sourcepub const fn tcd9_saddr(self) -> Reg<TcdSaddr, RW>
pub const fn tcd9_saddr(self) -> Reg<TcdSaddr, RW>
TCD Source Address
Sourcepub const fn tcd9_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>
pub const fn tcd9_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>
TCD Minor Byte Count (Minor Loop Mapping Disabled)
Sourcepub const fn tcd9_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>
pub const fn tcd9_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>
TCD Signed Minor Loop Offset (Minor Loop Mapping Enabled and Offset Disabled)
Sourcepub const fn tcd9_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>
pub const fn tcd9_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>
TCD Signed Minor Loop Offset (Minor Loop Mapping and Offset Enabled)
Sourcepub const fn tcd9_slast(self) -> Reg<TcdSlast, RW>
pub const fn tcd9_slast(self) -> Reg<TcdSlast, RW>
TCD Last Source Address Adjustment
Sourcepub const fn tcd9_daddr(self) -> Reg<TcdDaddr, RW>
pub const fn tcd9_daddr(self) -> Reg<TcdDaddr, RW>
TCD Destination Address
Sourcepub const fn tcd9_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>
pub const fn tcd9_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>
TCD Current Minor Loop Link, Major Loop Count (Channel Linking Disabled)
Sourcepub const fn tcd9_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>
pub const fn tcd9_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>
TCD Current Minor Loop Link, Major Loop Count (Channel Linking Enabled)
Sourcepub const fn tcd9_dlastsga(self) -> Reg<TcdDlastsga, RW>
pub const fn tcd9_dlastsga(self) -> Reg<TcdDlastsga, RW>
TCD Last Destination Address Adjustment/Scatter Gather Address
Sourcepub const fn tcd9_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>
pub const fn tcd9_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>
TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Disabled)
Sourcepub const fn tcd9_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>
pub const fn tcd9_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>
TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Enabled)
Sourcepub const fn tcd10_saddr(self) -> Reg<TcdSaddr, RW>
pub const fn tcd10_saddr(self) -> Reg<TcdSaddr, RW>
TCD Source Address
Sourcepub const fn tcd10_soff(self) -> Reg<TcdSoff, RW>
pub const fn tcd10_soff(self) -> Reg<TcdSoff, RW>
TCD Signed Source Address Offset
Sourcepub const fn tcd10_attr(self) -> Reg<TcdAttr, RW>
pub const fn tcd10_attr(self) -> Reg<TcdAttr, RW>
TCD Transfer Attributes
Sourcepub const fn tcd10_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>
pub const fn tcd10_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>
TCD Minor Byte Count (Minor Loop Mapping Disabled)
Sourcepub const fn tcd10_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>
pub const fn tcd10_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>
TCD Signed Minor Loop Offset (Minor Loop Mapping Enabled and Offset Disabled)
Sourcepub const fn tcd10_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>
pub const fn tcd10_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>
TCD Signed Minor Loop Offset (Minor Loop Mapping and Offset Enabled)
Sourcepub const fn tcd10_slast(self) -> Reg<TcdSlast, RW>
pub const fn tcd10_slast(self) -> Reg<TcdSlast, RW>
TCD Last Source Address Adjustment
Sourcepub const fn tcd10_daddr(self) -> Reg<TcdDaddr, RW>
pub const fn tcd10_daddr(self) -> Reg<TcdDaddr, RW>
TCD Destination Address
Sourcepub const fn tcd10_doff(self) -> Reg<TcdDoff, RW>
pub const fn tcd10_doff(self) -> Reg<TcdDoff, RW>
TCD Signed Destination Address Offset
Sourcepub const fn tcd10_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>
pub const fn tcd10_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>
TCD Current Minor Loop Link, Major Loop Count (Channel Linking Disabled)
Sourcepub const fn tcd10_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>
pub const fn tcd10_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>
TCD Current Minor Loop Link, Major Loop Count (Channel Linking Enabled)
Sourcepub const fn tcd10_dlastsga(self) -> Reg<TcdDlastsga, RW>
pub const fn tcd10_dlastsga(self) -> Reg<TcdDlastsga, RW>
TCD Last Destination Address Adjustment/Scatter Gather Address
Sourcepub const fn tcd10_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>
pub const fn tcd10_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>
TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Disabled)
Sourcepub const fn tcd10_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>
pub const fn tcd10_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>
TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Enabled)
Sourcepub const fn tcd11_saddr(self) -> Reg<TcdSaddr, RW>
pub const fn tcd11_saddr(self) -> Reg<TcdSaddr, RW>
TCD Source Address
Sourcepub const fn tcd11_soff(self) -> Reg<TcdSoff, RW>
pub const fn tcd11_soff(self) -> Reg<TcdSoff, RW>
TCD Signed Source Address Offset
Sourcepub const fn tcd11_attr(self) -> Reg<TcdAttr, RW>
pub const fn tcd11_attr(self) -> Reg<TcdAttr, RW>
TCD Transfer Attributes
Sourcepub const fn tcd11_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>
pub const fn tcd11_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>
TCD Minor Byte Count (Minor Loop Mapping Disabled)
Sourcepub const fn tcd11_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>
pub const fn tcd11_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>
TCD Signed Minor Loop Offset (Minor Loop Mapping Enabled and Offset Disabled)
Sourcepub const fn tcd11_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>
pub const fn tcd11_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>
TCD Signed Minor Loop Offset (Minor Loop Mapping and Offset Enabled)
Sourcepub const fn tcd11_slast(self) -> Reg<TcdSlast, RW>
pub const fn tcd11_slast(self) -> Reg<TcdSlast, RW>
TCD Last Source Address Adjustment
Sourcepub const fn tcd11_daddr(self) -> Reg<TcdDaddr, RW>
pub const fn tcd11_daddr(self) -> Reg<TcdDaddr, RW>
TCD Destination Address
Sourcepub const fn tcd11_doff(self) -> Reg<TcdDoff, RW>
pub const fn tcd11_doff(self) -> Reg<TcdDoff, RW>
TCD Signed Destination Address Offset
Sourcepub const fn tcd11_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>
pub const fn tcd11_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>
TCD Current Minor Loop Link, Major Loop Count (Channel Linking Disabled)
Sourcepub const fn tcd11_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>
pub const fn tcd11_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>
TCD Current Minor Loop Link, Major Loop Count (Channel Linking Enabled)
Sourcepub const fn tcd11_dlastsga(self) -> Reg<TcdDlastsga, RW>
pub const fn tcd11_dlastsga(self) -> Reg<TcdDlastsga, RW>
TCD Last Destination Address Adjustment/Scatter Gather Address
Sourcepub const fn tcd11_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>
pub const fn tcd11_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>
TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Disabled)
Sourcepub const fn tcd11_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>
pub const fn tcd11_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>
TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Enabled)
Sourcepub const fn tcd12_saddr(self) -> Reg<TcdSaddr, RW>
pub const fn tcd12_saddr(self) -> Reg<TcdSaddr, RW>
TCD Source Address
Sourcepub const fn tcd12_soff(self) -> Reg<TcdSoff, RW>
pub const fn tcd12_soff(self) -> Reg<TcdSoff, RW>
TCD Signed Source Address Offset
Sourcepub const fn tcd12_attr(self) -> Reg<TcdAttr, RW>
pub const fn tcd12_attr(self) -> Reg<TcdAttr, RW>
TCD Transfer Attributes
Sourcepub const fn tcd12_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>
pub const fn tcd12_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>
TCD Minor Byte Count (Minor Loop Mapping Disabled)
Sourcepub const fn tcd12_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>
pub const fn tcd12_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>
TCD Signed Minor Loop Offset (Minor Loop Mapping Enabled and Offset Disabled)
Sourcepub const fn tcd12_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>
pub const fn tcd12_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>
TCD Signed Minor Loop Offset (Minor Loop Mapping and Offset Enabled)
Sourcepub const fn tcd12_slast(self) -> Reg<TcdSlast, RW>
pub const fn tcd12_slast(self) -> Reg<TcdSlast, RW>
TCD Last Source Address Adjustment
Sourcepub const fn tcd12_daddr(self) -> Reg<TcdDaddr, RW>
pub const fn tcd12_daddr(self) -> Reg<TcdDaddr, RW>
TCD Destination Address
Sourcepub const fn tcd12_doff(self) -> Reg<TcdDoff, RW>
pub const fn tcd12_doff(self) -> Reg<TcdDoff, RW>
TCD Signed Destination Address Offset
Sourcepub const fn tcd12_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>
pub const fn tcd12_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>
TCD Current Minor Loop Link, Major Loop Count (Channel Linking Disabled)
Sourcepub const fn tcd12_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>
pub const fn tcd12_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>
TCD Current Minor Loop Link, Major Loop Count (Channel Linking Enabled)
Sourcepub const fn tcd12_dlastsga(self) -> Reg<TcdDlastsga, RW>
pub const fn tcd12_dlastsga(self) -> Reg<TcdDlastsga, RW>
TCD Last Destination Address Adjustment/Scatter Gather Address
Sourcepub const fn tcd12_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>
pub const fn tcd12_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>
TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Disabled)
Sourcepub const fn tcd12_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>
pub const fn tcd12_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>
TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Enabled)
Sourcepub const fn tcd13_saddr(self) -> Reg<TcdSaddr, RW>
pub const fn tcd13_saddr(self) -> Reg<TcdSaddr, RW>
TCD Source Address
Sourcepub const fn tcd13_soff(self) -> Reg<TcdSoff, RW>
pub const fn tcd13_soff(self) -> Reg<TcdSoff, RW>
TCD Signed Source Address Offset
Sourcepub const fn tcd13_attr(self) -> Reg<TcdAttr, RW>
pub const fn tcd13_attr(self) -> Reg<TcdAttr, RW>
TCD Transfer Attributes
Sourcepub const fn tcd13_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>
pub const fn tcd13_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>
TCD Minor Byte Count (Minor Loop Mapping Disabled)
Sourcepub const fn tcd13_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>
pub const fn tcd13_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>
TCD Signed Minor Loop Offset (Minor Loop Mapping Enabled and Offset Disabled)
Sourcepub const fn tcd13_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>
pub const fn tcd13_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>
TCD Signed Minor Loop Offset (Minor Loop Mapping and Offset Enabled)
Sourcepub const fn tcd13_slast(self) -> Reg<TcdSlast, RW>
pub const fn tcd13_slast(self) -> Reg<TcdSlast, RW>
TCD Last Source Address Adjustment
Sourcepub const fn tcd13_daddr(self) -> Reg<TcdDaddr, RW>
pub const fn tcd13_daddr(self) -> Reg<TcdDaddr, RW>
TCD Destination Address
Sourcepub const fn tcd13_doff(self) -> Reg<TcdDoff, RW>
pub const fn tcd13_doff(self) -> Reg<TcdDoff, RW>
TCD Signed Destination Address Offset
Sourcepub const fn tcd13_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>
pub const fn tcd13_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>
TCD Current Minor Loop Link, Major Loop Count (Channel Linking Disabled)
Sourcepub const fn tcd13_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>
pub const fn tcd13_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>
TCD Current Minor Loop Link, Major Loop Count (Channel Linking Enabled)
Sourcepub const fn tcd13_dlastsga(self) -> Reg<TcdDlastsga, RW>
pub const fn tcd13_dlastsga(self) -> Reg<TcdDlastsga, RW>
TCD Last Destination Address Adjustment/Scatter Gather Address
Sourcepub const fn tcd13_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>
pub const fn tcd13_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>
TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Disabled)
Sourcepub const fn tcd13_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>
pub const fn tcd13_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>
TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Enabled)
Sourcepub const fn tcd14_saddr(self) -> Reg<TcdSaddr, RW>
pub const fn tcd14_saddr(self) -> Reg<TcdSaddr, RW>
TCD Source Address
Sourcepub const fn tcd14_soff(self) -> Reg<TcdSoff, RW>
pub const fn tcd14_soff(self) -> Reg<TcdSoff, RW>
TCD Signed Source Address Offset
Sourcepub const fn tcd14_attr(self) -> Reg<TcdAttr, RW>
pub const fn tcd14_attr(self) -> Reg<TcdAttr, RW>
TCD Transfer Attributes
Sourcepub const fn tcd14_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>
pub const fn tcd14_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>
TCD Minor Byte Count (Minor Loop Mapping Disabled)
Sourcepub const fn tcd14_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>
pub const fn tcd14_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>
TCD Signed Minor Loop Offset (Minor Loop Mapping Enabled and Offset Disabled)
Sourcepub const fn tcd14_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>
pub const fn tcd14_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>
TCD Signed Minor Loop Offset (Minor Loop Mapping and Offset Enabled)
Sourcepub const fn tcd14_slast(self) -> Reg<TcdSlast, RW>
pub const fn tcd14_slast(self) -> Reg<TcdSlast, RW>
TCD Last Source Address Adjustment
Sourcepub const fn tcd14_daddr(self) -> Reg<TcdDaddr, RW>
pub const fn tcd14_daddr(self) -> Reg<TcdDaddr, RW>
TCD Destination Address
Sourcepub const fn tcd14_doff(self) -> Reg<TcdDoff, RW>
pub const fn tcd14_doff(self) -> Reg<TcdDoff, RW>
TCD Signed Destination Address Offset
Sourcepub const fn tcd14_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>
pub const fn tcd14_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>
TCD Current Minor Loop Link, Major Loop Count (Channel Linking Disabled)
Sourcepub const fn tcd14_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>
pub const fn tcd14_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>
TCD Current Minor Loop Link, Major Loop Count (Channel Linking Enabled)
Sourcepub const fn tcd14_dlastsga(self) -> Reg<TcdDlastsga, RW>
pub const fn tcd14_dlastsga(self) -> Reg<TcdDlastsga, RW>
TCD Last Destination Address Adjustment/Scatter Gather Address
Sourcepub const fn tcd14_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>
pub const fn tcd14_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>
TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Disabled)
Sourcepub const fn tcd14_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>
pub const fn tcd14_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>
TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Enabled)
Sourcepub const fn tcd15_saddr(self) -> Reg<TcdSaddr, RW>
pub const fn tcd15_saddr(self) -> Reg<TcdSaddr, RW>
TCD Source Address
Sourcepub const fn tcd15_soff(self) -> Reg<TcdSoff, RW>
pub const fn tcd15_soff(self) -> Reg<TcdSoff, RW>
TCD Signed Source Address Offset
Sourcepub const fn tcd15_attr(self) -> Reg<TcdAttr, RW>
pub const fn tcd15_attr(self) -> Reg<TcdAttr, RW>
TCD Transfer Attributes
Sourcepub const fn tcd15_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>
pub const fn tcd15_nbytes_mlno(self) -> Reg<TcdNbytesMlno, RW>
TCD Minor Byte Count (Minor Loop Mapping Disabled)
Sourcepub const fn tcd15_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>
pub const fn tcd15_nbytes_mloffno(self) -> Reg<TcdNbytesMloffno, RW>
TCD Signed Minor Loop Offset (Minor Loop Mapping Enabled and Offset Disabled)
Sourcepub const fn tcd15_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>
pub const fn tcd15_nbytes_mloffyes(self) -> Reg<TcdNbytesMloffyes, RW>
TCD Signed Minor Loop Offset (Minor Loop Mapping and Offset Enabled)
Sourcepub const fn tcd15_slast(self) -> Reg<TcdSlast, RW>
pub const fn tcd15_slast(self) -> Reg<TcdSlast, RW>
TCD Last Source Address Adjustment
Sourcepub const fn tcd15_daddr(self) -> Reg<TcdDaddr, RW>
pub const fn tcd15_daddr(self) -> Reg<TcdDaddr, RW>
TCD Destination Address
Sourcepub const fn tcd15_doff(self) -> Reg<TcdDoff, RW>
pub const fn tcd15_doff(self) -> Reg<TcdDoff, RW>
TCD Signed Destination Address Offset
Sourcepub const fn tcd15_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>
pub const fn tcd15_citer_elinkno(self) -> Reg<TcdCiterElinkno, RW>
TCD Current Minor Loop Link, Major Loop Count (Channel Linking Disabled)
Sourcepub const fn tcd15_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>
pub const fn tcd15_citer_elinkyes(self) -> Reg<TcdCiterElinkyes, RW>
TCD Current Minor Loop Link, Major Loop Count (Channel Linking Enabled)
Sourcepub const fn tcd15_dlastsga(self) -> Reg<TcdDlastsga, RW>
pub const fn tcd15_dlastsga(self) -> Reg<TcdDlastsga, RW>
TCD Last Destination Address Adjustment/Scatter Gather Address
Sourcepub const fn tcd15_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>
pub const fn tcd15_biter_elinkno(self) -> Reg<TcdBiterElinkno, RW>
TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Disabled)
Sourcepub const fn tcd15_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>
pub const fn tcd15_biter_elinkyes(self) -> Reg<TcdBiterElinkyes, RW>
TCD Beginning Minor Loop Link, Major Loop Count (Channel Linking Enabled)